@@ -54,3 +54,5 @@ from pyvalidator.is_regex import is_regex
 from pyvalidator.is_css_unit import is_css_unit
 from pyvalidator.is_url import is_url
 from pyvalidator.is_mac_address import is_mac_address
+from pyvalidator.is_odd import is_odd
+from pyvalidator.is_even import is_even
